#include <kdialog.h>
#include <klocale.h>

#include "/usr/src/ports/kfilereplace/kfilereplace-17.08.3-1.i686/build/knewprojectdlgs.h"

#include <qvariant.h>
/*
 *  Constructs a KNewProjectDlgS as a child of 'parent', with the
 *  name 'name' and widget flags set to 'f'.
 *
 *  The dialog will by default be modeless, unless you set 'modal' to
 *  true to construct a modal dialog.
 */
KNewProjectDlgS::KNewProjectDlgS(QWidget* parent, const char* name, bool modal, Qt::WindowFlags fl)
    : QDialog(parent, name, modal, fl)
{
    setupUi(this);

}

/*
 *  Destroys the object and frees any allocated resources
 */
KNewProjectDlgS::~KNewProjectDlgS()
{
    // no need to delete child widgets, Qt does it all for us
}

/*
 *  Sets the strings of the subwidgets using the current
 *  language.
 */
void KNewProjectDlgS::languageChange()
{
    retranslateUi(this);
}


